*ndispers* is a Python3 package for calculating refractive index dispersion of various crystals and glasses commonly used in the field of nonlinear/ultrafast optics.
It allows you to calculate refractive index and its derivative quantities, such as group velocity, group index, group velocity dispersion,  third-order dispersion, walkoff angles, as a function of 1) wavelength of light, 2) polar (theta) or azimuthal (phi) angles of wave vector with respect to dielectric principal axes of anisotropic crystals, 3) crystal temperature, and 4) polarization of light (ordinary- or extraordinary-ray).
As this package provides those functions with the methods of an medium object, one can easily implement it to other numerical simulations in nonlinear/ultrafast optics.